@@ -32,7 +32,9 @@ __all__ = (
     "InvocationTypeType",
     "PushNotificationTypeType",
     "SortOrderType",
+    "ChimeSDKMessagingServiceName",
     "ServiceName",
+    "ResourceServiceName",
 )
 
 
@@ -64,6 +66,7 @@ FallbackActionType = Literal["ABORT", "CONTINUE"]
 InvocationTypeType = Literal["ASYNC"]
 PushNotificationTypeType = Literal["DEFAULT", "VOIP"]
 SortOrderType = Literal["ASCENDING", "DESCENDING"]
+ChimeSDKMessagingServiceName = Literal["chime-sdk-messaging"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -95,6 +98,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -217,6 +221,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -365,3 +370,15 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
