@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence, Union
 
+from typing_extensions import NotRequired
+
 from .literals import (
     AllowNotificationsType,
     ChannelMembershipTypeType,
@@ -155,10 +157,9 @@ __all__ = (
 AppInstanceUserMembershipSummaryTypeDef = TypedDict(
     "AppInstanceUserMembershipSummaryTypeDef",
     {
-        "Type": ChannelMembershipTypeType,
-        "ReadMarkerTimestamp": datetime,
+        "Type": NotRequired[ChannelMembershipTypeType],
+        "ReadMarkerTimestamp": NotRequired[datetime],
     },
-    total=False,
 )
 
 AssociateChannelFlowRequestRequestTypeDef = TypedDict(
@@ -173,47 +174,31 @@ AssociateChannelFlowRequestRequestTypeDef = TypedDict(
 BatchChannelMembershipsTypeDef = TypedDict(
     "BatchChannelMembershipsTypeDef",
     {
-        "InvitedBy": "IdentityTypeDef",
-        "Type": ChannelMembershipTypeType,
-        "Members": List["IdentityTypeDef"],
-        "ChannelArn": str,
+        "InvitedBy": NotRequired["IdentityTypeDef"],
+        "Type": NotRequired[ChannelMembershipTypeType],
+        "Members": NotRequired[List["IdentityTypeDef"]],
+        "ChannelArn": NotRequired[str],
     },
-    total=False,
 )
 
 BatchCreateChannelMembershipErrorTypeDef = TypedDict(
     "BatchCreateChannelMembershipErrorTypeDef",
     {
-        "MemberArn": str,
-        "ErrorCode": ErrorCodeType,
-        "ErrorMessage": str,
+        "MemberArn": NotRequired[str],
+        "ErrorCode": NotRequired[ErrorCodeType],
+        "ErrorMessage": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredBatchCreateChannelMembershipRequestRequestTypeDef = TypedDict(
-    "_RequiredBatchCreateChannelMembershipRequestRequestTypeDef",
+BatchCreateChannelMembershipRequestRequestTypeDef = TypedDict(
+    "BatchCreateChannelMembershipRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "MemberArns": Sequence[str],
         "ChimeBearer": str,
+        "Type": NotRequired[ChannelMembershipTypeType],
     },
 )
-_OptionalBatchCreateChannelMembershipRequestRequestTypeDef = TypedDict(
-    "_OptionalBatchCreateChannelMembershipRequestRequestTypeDef",
-    {
-        "Type": ChannelMembershipTypeType,
-    },
-    total=False,
-)
-
-
-class BatchCreateChannelMembershipRequestRequestTypeDef(
-    _RequiredBatchCreateChannelMembershipRequestRequestTypeDef,
-    _OptionalBatchCreateChannelMembershipRequestRequestTypeDef,
-):
-    pass
-
 
 BatchCreateChannelMembershipResponseTypeDef = TypedDict(
     "BatchCreateChannelMembershipResponseTypeDef",
@@ -227,57 +212,40 @@ BatchCreateChannelMembershipResponseTypeDef = TypedDict(
 ChannelAssociatedWithFlowSummaryTypeDef = TypedDict(
     "ChannelAssociatedWithFlowSummaryTypeDef",
     {
-        "Name": str,
-        "ChannelArn": str,
-        "Mode": ChannelModeType,
-        "Privacy": ChannelPrivacyType,
-        "Metadata": str,
+        "Name": NotRequired[str],
+        "ChannelArn": NotRequired[str],
+        "Mode": NotRequired[ChannelModeType],
+        "Privacy": NotRequired[ChannelPrivacyType],
+        "Metadata": NotRequired[str],
     },
-    total=False,
 )
 
 ChannelBanSummaryTypeDef = TypedDict(
     "ChannelBanSummaryTypeDef",
     {
-        "Member": "IdentityTypeDef",
+        "Member": NotRequired["IdentityTypeDef"],
     },
-    total=False,
 )
 
 ChannelBanTypeDef = TypedDict(
     "ChannelBanTypeDef",
     {
-        "Member": "IdentityTypeDef",
-        "ChannelArn": str,
-        "CreatedTimestamp": datetime,
-        "CreatedBy": "IdentityTypeDef",
+        "Member": NotRequired["IdentityTypeDef"],
+        "ChannelArn": NotRequired[str],
+        "CreatedTimestamp": NotRequired[datetime],
+        "CreatedBy": NotRequired["IdentityTypeDef"],
     },
-    total=False,
 )
 
-_RequiredChannelFlowCallbackRequestRequestTypeDef = TypedDict(
-    "_RequiredChannelFlowCallbackRequestRequestTypeDef",
+ChannelFlowCallbackRequestRequestTypeDef = TypedDict(
+    "ChannelFlowCallbackRequestRequestTypeDef",
     {
         "CallbackId": str,
         "ChannelArn": str,
         "ChannelMessage": "ChannelMessageCallbackTypeDef",
+        "DeleteResource": NotRequired[bool],
     },
 )
-_OptionalChannelFlowCallbackRequestRequestTypeDef = TypedDict(
-    "_OptionalChannelFlowCallbackRequestRequestTypeDef",
-    {
-        "DeleteResource": bool,
-    },
-    total=False,
-)
-
-
-class ChannelFlowCallbackRequestRequestTypeDef(
-    _RequiredChannelFlowCallbackRequestRequestTypeDef,
-    _OptionalChannelFlowCallbackRequestRequestTypeDef,
-):
-    pass
-
 
 ChannelFlowCallbackResponseTypeDef = TypedDict(
     "ChannelFlowCallbackResponseTypeDef",
@@ -291,189 +259,162 @@ ChannelFlowCallbackResponseTypeDef = TypedDict(
 ChannelFlowSummaryTypeDef = TypedDict(
     "ChannelFlowSummaryTypeDef",
     {
-        "ChannelFlowArn": str,
-        "Name": str,
-        "Processors": List["ProcessorTypeDef"],
+        "ChannelFlowArn": NotRequired[str],
+        "Name": NotRequired[str],
+        "Processors": NotRequired[List["ProcessorTypeDef"]],
     },
-    total=False,
 )
 
 ChannelFlowTypeDef = TypedDict(
     "ChannelFlowTypeDef",
     {
-        "ChannelFlowArn": str,
-        "Processors": List["ProcessorTypeDef"],
-        "Name": str,
-        "CreatedTimestamp": datetime,
-        "LastUpdatedTimestamp": datetime,
+        "ChannelFlowArn": NotRequired[str],
+        "Processors": NotRequired[List["ProcessorTypeDef"]],
+        "Name": NotRequired[str],
+        "CreatedTimestamp": NotRequired[datetime],
+        "LastUpdatedTimestamp": NotRequired[datetime],
     },
-    total=False,
 )
 
 ChannelMembershipForAppInstanceUserSummaryTypeDef = TypedDict(
     "ChannelMembershipForAppInstanceUserSummaryTypeDef",
     {
-        "ChannelSummary": "ChannelSummaryTypeDef",
-        "AppInstanceUserMembershipSummary": "AppInstanceUserMembershipSummaryTypeDef",
+        "ChannelSummary": NotRequired["ChannelSummaryTypeDef"],
+        "AppInstanceUserMembershipSummary": NotRequired["AppInstanceUserMembershipSummaryTypeDef"],
     },
-    total=False,
 )
 
 ChannelMembershipPreferencesTypeDef = TypedDict(
     "ChannelMembershipPreferencesTypeDef",
     {
-        "PushNotifications": "PushNotificationPreferencesTypeDef",
+        "PushNotifications": NotRequired["PushNotificationPreferencesTypeDef"],
     },
-    total=False,
 )
 
 ChannelMembershipSummaryTypeDef = TypedDict(
     "ChannelMembershipSummaryTypeDef",
     {
-        "Member": "IdentityTypeDef",
+        "Member": NotRequired["IdentityTypeDef"],
     },
-    total=False,
 )
 
 ChannelMembershipTypeDef = TypedDict(
     "ChannelMembershipTypeDef",
     {
-        "InvitedBy": "IdentityTypeDef",
-        "Type": ChannelMembershipTypeType,
-        "Member": "IdentityTypeDef",
-        "ChannelArn": str,
-        "CreatedTimestamp": datetime,
-        "LastUpdatedTimestamp": datetime,
+        "InvitedBy": NotRequired["IdentityTypeDef"],
+        "Type": NotRequired[ChannelMembershipTypeType],
+        "Member": NotRequired["IdentityTypeDef"],
+        "ChannelArn": NotRequired[str],
+        "CreatedTimestamp": NotRequired[datetime],
+        "LastUpdatedTimestamp": NotRequired[datetime],
     },
-    total=False,
 )
 
-_RequiredChannelMessageCallbackTypeDef = TypedDict(
-    "_RequiredChannelMessageCallbackTypeDef",
+ChannelMessageCallbackTypeDef = TypedDict(
+    "ChannelMessageCallbackTypeDef",
     {
         "MessageId": str,
+        "Content": NotRequired[str],
+        "Metadata": NotRequired[str],
+        "PushNotification": NotRequired["PushNotificationConfigurationTypeDef"],
+        "MessageAttributes": NotRequired[Mapping[str, "MessageAttributeValueTypeDef"]],
     },
 )
-_OptionalChannelMessageCallbackTypeDef = TypedDict(
-    "_OptionalChannelMessageCallbackTypeDef",
-    {
-        "Content": str,
-        "Metadata": str,
-        "PushNotification": "PushNotificationConfigurationTypeDef",
-        "MessageAttributes": Mapping[str, "MessageAttributeValueTypeDef"],
-    },
-    total=False,
-)
-
-
-class ChannelMessageCallbackTypeDef(
-    _RequiredChannelMessageCallbackTypeDef, _OptionalChannelMessageCallbackTypeDef
-):
-    pass
-
 
 ChannelMessageStatusStructureTypeDef = TypedDict(
     "ChannelMessageStatusStructureTypeDef",
     {
-        "Value": ChannelMessageStatusType,
-        "Detail": str,
+        "Value": NotRequired[ChannelMessageStatusType],
+        "Detail": NotRequired[str],
     },
-    total=False,
 )
 
 ChannelMessageSummaryTypeDef = TypedDict(
     "ChannelMessageSummaryTypeDef",
     {
-        "MessageId": str,
-        "Content": str,
-        "Metadata": str,
-        "Type": ChannelMessageTypeType,
-        "CreatedTimestamp": datetime,
-        "LastUpdatedTimestamp": datetime,
-        "LastEditedTimestamp": datetime,
-        "Sender": "IdentityTypeDef",
-        "Redacted": bool,
-        "Status": "ChannelMessageStatusStructureTypeDef",
-        "MessageAttributes": Dict[str, "MessageAttributeValueTypeDef"],
+        "MessageId": NotRequired[str],
+        "Content": NotRequired[str],
+        "Metadata": NotRequired[str],
+        "Type": NotRequired[ChannelMessageTypeType],
+        "CreatedTimestamp": NotRequired[datetime],
+        "LastUpdatedTimestamp": NotRequired[datetime],
+        "LastEditedTimestamp": NotRequired[datetime],
+        "Sender": NotRequired["IdentityTypeDef"],
+        "Redacted": NotRequired[bool],
+        "Status": NotRequired["ChannelMessageStatusStructureTypeDef"],
+        "MessageAttributes": NotRequired[Dict[str, "MessageAttributeValueTypeDef"]],
     },
-    total=False,
 )
 
 ChannelMessageTypeDef = TypedDict(
     "ChannelMessageTypeDef",
     {
-        "ChannelArn": str,
-        "MessageId": str,
-        "Content": str,
-        "Metadata": str,
-        "Type": ChannelMessageTypeType,
-        "CreatedTimestamp": datetime,
-        "LastEditedTimestamp": datetime,
-        "LastUpdatedTimestamp": datetime,
-        "Sender": "IdentityTypeDef",
-        "Redacted": bool,
-        "Persistence": ChannelMessagePersistenceTypeType,
-        "Status": "ChannelMessageStatusStructureTypeDef",
-        "MessageAttributes": Dict[str, "MessageAttributeValueTypeDef"],
+        "ChannelArn": NotRequired[str],
+        "MessageId": NotRequired[str],
+        "Content": NotRequired[str],
+        "Metadata": NotRequired[str],
+        "Type": NotRequired[ChannelMessageTypeType],
+        "CreatedTimestamp": NotRequired[datetime],
+        "LastEditedTimestamp": NotRequired[datetime],
+        "LastUpdatedTimestamp": NotRequired[datetime],
+        "Sender": NotRequired["IdentityTypeDef"],
+        "Redacted": NotRequired[bool],
+        "Persistence": NotRequired[ChannelMessagePersistenceTypeType],
+        "Status": NotRequired["ChannelMessageStatusStructureTypeDef"],
+        "MessageAttributes": NotRequired[Dict[str, "MessageAttributeValueTypeDef"]],
     },
-    total=False,
 )
 
 ChannelModeratedByAppInstanceUserSummaryTypeDef = TypedDict(
     "ChannelModeratedByAppInstanceUserSummaryTypeDef",
     {
-        "ChannelSummary": "ChannelSummaryTypeDef",
+        "ChannelSummary": NotRequired["ChannelSummaryTypeDef"],
     },
-    total=False,
 )
 
 ChannelModeratorSummaryTypeDef = TypedDict(
     "ChannelModeratorSummaryTypeDef",
     {
-        "Moderator": "IdentityTypeDef",
+        "Moderator": NotRequired["IdentityTypeDef"],
     },
-    total=False,
 )
 
 ChannelModeratorTypeDef = TypedDict(
     "ChannelModeratorTypeDef",
     {
-        "Moderator": "IdentityTypeDef",
-        "ChannelArn": str,
-        "CreatedTimestamp": datetime,
-        "CreatedBy": "IdentityTypeDef",
+        "Moderator": NotRequired["IdentityTypeDef"],
+        "ChannelArn": NotRequired[str],
+        "CreatedTimestamp": NotRequired[datetime],
+        "CreatedBy": NotRequired["IdentityTypeDef"],
     },
-    total=False,
 )
 
 ChannelSummaryTypeDef = TypedDict(
     "ChannelSummaryTypeDef",
     {
-        "Name": str,
-        "ChannelArn": str,
-        "Mode": ChannelModeType,
-        "Privacy": ChannelPrivacyType,
-        "Metadata": str,
-        "LastMessageTimestamp": datetime,
+        "Name": NotRequired[str],
+        "ChannelArn": NotRequired[str],
+        "Mode": NotRequired[ChannelModeType],
+        "Privacy": NotRequired[ChannelPrivacyType],
+        "Metadata": NotRequired[str],
+        "LastMessageTimestamp": NotRequired[datetime],
     },
-    total=False,
 )
 
 ChannelTypeDef = TypedDict(
     "ChannelTypeDef",
     {
-        "Name": str,
-        "ChannelArn": str,
-        "Mode": ChannelModeType,
-        "Privacy": ChannelPrivacyType,
-        "Metadata": str,
-        "CreatedBy": "IdentityTypeDef",
-        "CreatedTimestamp": datetime,
-        "LastMessageTimestamp": datetime,
-        "LastUpdatedTimestamp": datetime,
-        "ChannelFlowArn": str,
+        "Name": NotRequired[str],
+        "ChannelArn": NotRequired[str],
+        "Mode": NotRequired[ChannelModeType],
+        "Privacy": NotRequired[ChannelPrivacyType],
+        "Metadata": NotRequired[str],
+        "CreatedBy": NotRequired["IdentityTypeDef"],
+        "CreatedTimestamp": NotRequired[datetime],
+        "LastMessageTimestamp": NotRequired[datetime],
+        "LastUpdatedTimestamp": NotRequired[datetime],
+        "ChannelFlowArn": NotRequired[str],
     },
-    total=False,
 )
 
 CreateChannelBanRequestRequestTypeDef = TypedDict(
@@ -494,29 +435,16 @@ CreateChannelBanResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateChannelFlowRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateChannelFlowRequestRequestTypeDef",
+CreateChannelFlowRequestRequestTypeDef = TypedDict(
+    "CreateChannelFlowRequestRequestTypeDef",
     {
         "AppInstanceArn": str,
         "Processors": Sequence["ProcessorTypeDef"],
         "Name": str,
         "ClientRequestToken": str,
+        "Tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
-_OptionalCreateChannelFlowRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateChannelFlowRequestRequestTypeDef",
-    {
-        "Tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateChannelFlowRequestRequestTypeDef(
-    _RequiredCreateChannelFlowRequestRequestTypeDef, _OptionalCreateChannelFlowRequestRequestTypeDef
-):
-    pass
-
 
 CreateChannelFlowResponseTypeDef = TypedDict(
     "CreateChannelFlowResponseTypeDef",
@@ -563,32 +491,19 @@ CreateChannelModeratorResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateChannelRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateChannelRequestRequestTypeDef",
+CreateChannelRequestRequestTypeDef = TypedDict(
+    "CreateChannelRequestRequestTypeDef",
     {
         "AppInstanceArn": str,
         "Name": str,
         "ClientRequestToken": str,
         "ChimeBearer": str,
+        "Mode": NotRequired[ChannelModeType],
+        "Privacy": NotRequired[ChannelPrivacyType],
+        "Metadata": NotRequired[str],
+        "Tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
-_OptionalCreateChannelRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateChannelRequestRequestTypeDef",
-    {
-        "Mode": ChannelModeType,
-        "Privacy": ChannelPrivacyType,
-        "Metadata": str,
-        "Tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateChannelRequestRequestTypeDef(
-    _RequiredCreateChannelRequestRequestTypeDef, _OptionalCreateChannelRequestRequestTypeDef
-):
-    pass
-
 
 CreateChannelResponseTypeDef = TypedDict(
     "CreateChannelResponseTypeDef",
@@ -838,10 +753,9 @@ GetMessagingSessionEndpointResponseTypeDef = TypedDict(
 IdentityTypeDef = TypedDict(
     "IdentityTypeDef",
     {
-        "Arn": str,
-        "Name": str,
+        "Arn": NotRequired[str],
+        "Name": NotRequired[str],
     },
-    total=False,
 )
 
 LambdaConfigurationTypeDef = TypedDict(
@@ -852,28 +766,15 @@ LambdaConfigurationTypeDef = TypedDict(
     },
 )
 
-_RequiredListChannelBansRequestRequestTypeDef = TypedDict(
-    "_RequiredListChannelBansRequestRequestTypeDef",
+ListChannelBansRequestRequestTypeDef = TypedDict(
+    "ListChannelBansRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "ChimeBearer": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListChannelBansRequestRequestTypeDef = TypedDict(
-    "_OptionalListChannelBansRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListChannelBansRequestRequestTypeDef(
-    _RequiredListChannelBansRequestRequestTypeDef, _OptionalListChannelBansRequestRequestTypeDef
-):
-    pass
-
 
 ListChannelBansResponseTypeDef = TypedDict(
     "ListChannelBansResponseTypeDef",
@@ -885,27 +786,14 @@ ListChannelBansResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListChannelFlowsRequestRequestTypeDef = TypedDict(
-    "_RequiredListChannelFlowsRequestRequestTypeDef",
+ListChannelFlowsRequestRequestTypeDef = TypedDict(
+    "ListChannelFlowsRequestRequestTypeDef",
     {
         "AppInstanceArn": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListChannelFlowsRequestRequestTypeDef = TypedDict(
-    "_OptionalListChannelFlowsRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListChannelFlowsRequestRequestTypeDef(
-    _RequiredListChannelFlowsRequestRequestTypeDef, _OptionalListChannelFlowsRequestRequestTypeDef
-):
-    pass
-
 
 ListChannelFlowsResponseTypeDef = TypedDict(
     "ListChannelFlowsResponseTypeDef",
@@ -916,29 +804,15 @@ ListChannelFlowsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListChannelMembershipsForAppInstanceUserRequestRequestTypeDef = TypedDict(
-    "_RequiredListChannelMembershipsForAppInstanceUserRequestRequestTypeDef",
+ListChannelMembershipsForAppInstanceUserRequestRequestTypeDef = TypedDict(
+    "ListChannelMembershipsForAppInstanceUserRequestRequestTypeDef",
     {
         "ChimeBearer": str,
+        "AppInstanceUserArn": NotRequired[str],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListChannelMembershipsForAppInstanceUserRequestRequestTypeDef = TypedDict(
-    "_OptionalListChannelMembershipsForAppInstanceUserRequestRequestTypeDef",
-    {
-        "AppInstanceUserArn": str,
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListChannelMembershipsForAppInstanceUserRequestRequestTypeDef(
-    _RequiredListChannelMembershipsForAppInstanceUserRequestRequestTypeDef,
-    _OptionalListChannelMembershipsForAppInstanceUserRequestRequestTypeDef,
-):
-    pass
-
 
 ListChannelMembershipsForAppInstanceUserResponseTypeDef = TypedDict(
     "ListChannelMembershipsForAppInstanceUserResponseTypeDef",
@@ -949,30 +823,16 @@ ListChannelMembershipsForAppInstanceUserResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListChannelMembershipsRequestRequestTypeDef = TypedDict(
-    "_RequiredListChannelMembershipsRequestRequestTypeDef",
+ListChannelMembershipsRequestRequestTypeDef = TypedDict(
+    "ListChannelMembershipsRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "ChimeBearer": str,
+        "Type": NotRequired[ChannelMembershipTypeType],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListChannelMembershipsRequestRequestTypeDef = TypedDict(
-    "_OptionalListChannelMembershipsRequestRequestTypeDef",
-    {
-        "Type": ChannelMembershipTypeType,
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListChannelMembershipsRequestRequestTypeDef(
-    _RequiredListChannelMembershipsRequestRequestTypeDef,
-    _OptionalListChannelMembershipsRequestRequestTypeDef,
-):
-    pass
-
 
 ListChannelMembershipsResponseTypeDef = TypedDict(
     "ListChannelMembershipsResponseTypeDef",
@@ -984,32 +844,18 @@ ListChannelMembershipsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListChannelMessagesRequestRequestTypeDef = TypedDict(
-    "_RequiredListChannelMessagesRequestRequestTypeDef",
+ListChannelMessagesRequestRequestTypeDef = TypedDict(
+    "ListChannelMessagesRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "ChimeBearer": str,
+        "SortOrder": NotRequired[SortOrderType],
+        "NotBefore": NotRequired[Union[datetime, str]],
+        "NotAfter": NotRequired[Union[datetime, str]],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListChannelMessagesRequestRequestTypeDef = TypedDict(
-    "_OptionalListChannelMessagesRequestRequestTypeDef",
-    {
-        "SortOrder": SortOrderType,
-        "NotBefore": Union[datetime, str],
-        "NotAfter": Union[datetime, str],
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListChannelMessagesRequestRequestTypeDef(
-    _RequiredListChannelMessagesRequestRequestTypeDef,
-    _OptionalListChannelMessagesRequestRequestTypeDef,
-):
-    pass
-
 
 ListChannelMessagesResponseTypeDef = TypedDict(
     "ListChannelMessagesResponseTypeDef",
@@ -1021,29 +867,15 @@ ListChannelMessagesResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListChannelModeratorsRequestRequestTypeDef = TypedDict(
-    "_RequiredListChannelModeratorsRequestRequestTypeDef",
+ListChannelModeratorsRequestRequestTypeDef = TypedDict(
+    "ListChannelModeratorsRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "ChimeBearer": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListChannelModeratorsRequestRequestTypeDef = TypedDict(
-    "_OptionalListChannelModeratorsRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListChannelModeratorsRequestRequestTypeDef(
-    _RequiredListChannelModeratorsRequestRequestTypeDef,
-    _OptionalListChannelModeratorsRequestRequestTypeDef,
-):
-    pass
-
 
 ListChannelModeratorsResponseTypeDef = TypedDict(
     "ListChannelModeratorsResponseTypeDef",
@@ -1055,28 +887,14 @@ ListChannelModeratorsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListChannelsAssociatedWithChannelFlowRequestRequestTypeDef = TypedDict(
-    "_RequiredListChannelsAssociatedWithChannelFlowRequestRequestTypeDef",
+ListChannelsAssociatedWithChannelFlowRequestRequestTypeDef = TypedDict(
+    "ListChannelsAssociatedWithChannelFlowRequestRequestTypeDef",
     {
         "ChannelFlowArn": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListChannelsAssociatedWithChannelFlowRequestRequestTypeDef = TypedDict(
-    "_OptionalListChannelsAssociatedWithChannelFlowRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListChannelsAssociatedWithChannelFlowRequestRequestTypeDef(
-    _RequiredListChannelsAssociatedWithChannelFlowRequestRequestTypeDef,
-    _OptionalListChannelsAssociatedWithChannelFlowRequestRequestTypeDef,
-):
-    pass
-
 
 ListChannelsAssociatedWithChannelFlowResponseTypeDef = TypedDict(
     "ListChannelsAssociatedWithChannelFlowResponseTypeDef",
@@ -1087,29 +905,15 @@ ListChannelsAssociatedWithChannelFlowResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListChannelsModeratedByAppInstanceUserRequestRequestTypeDef = TypedDict(
-    "_RequiredListChannelsModeratedByAppInstanceUserRequestRequestTypeDef",
+ListChannelsModeratedByAppInstanceUserRequestRequestTypeDef = TypedDict(
+    "ListChannelsModeratedByAppInstanceUserRequestRequestTypeDef",
     {
         "ChimeBearer": str,
+        "AppInstanceUserArn": NotRequired[str],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListChannelsModeratedByAppInstanceUserRequestRequestTypeDef = TypedDict(
-    "_OptionalListChannelsModeratedByAppInstanceUserRequestRequestTypeDef",
-    {
-        "AppInstanceUserArn": str,
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListChannelsModeratedByAppInstanceUserRequestRequestTypeDef(
-    _RequiredListChannelsModeratedByAppInstanceUserRequestRequestTypeDef,
-    _OptionalListChannelsModeratedByAppInstanceUserRequestRequestTypeDef,
-):
-    pass
-
 
 ListChannelsModeratedByAppInstanceUserResponseTypeDef = TypedDict(
     "ListChannelsModeratedByAppInstanceUserResponseTypeDef",
@@ -1120,29 +924,16 @@ ListChannelsModeratedByAppInstanceUserResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListChannelsRequestRequestTypeDef = TypedDict(
-    "_RequiredListChannelsRequestRequestTypeDef",
+ListChannelsRequestRequestTypeDef = TypedDict(
+    "ListChannelsRequestRequestTypeDef",
     {
         "AppInstanceArn": str,
         "ChimeBearer": str,
+        "Privacy": NotRequired[ChannelPrivacyType],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListChannelsRequestRequestTypeDef = TypedDict(
-    "_OptionalListChannelsRequestRequestTypeDef",
-    {
-        "Privacy": ChannelPrivacyType,
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListChannelsRequestRequestTypeDef(
-    _RequiredListChannelsRequestRequestTypeDef, _OptionalListChannelsRequestRequestTypeDef
-):
-    pass
-
 
 ListChannelsResponseTypeDef = TypedDict(
     "ListChannelsResponseTypeDef",
@@ -1171,17 +962,15 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 MessageAttributeValueTypeDef = TypedDict(
     "MessageAttributeValueTypeDef",
     {
-        "StringValues": Sequence[str],
+        "StringValues": NotRequired[Sequence[str]],
     },
-    total=False,
 )
 
 MessagingSessionEndpointTypeDef = TypedDict(
     "MessagingSessionEndpointTypeDef",
     {
-        "Url": str,
+        "Url": NotRequired[str],
     },
-    total=False,
 )
 
 ProcessorConfigurationTypeDef = TypedDict(
@@ -1204,33 +993,19 @@ ProcessorTypeDef = TypedDict(
 PushNotificationConfigurationTypeDef = TypedDict(
     "PushNotificationConfigurationTypeDef",
     {
-        "Title": str,
-        "Body": str,
-        "Type": PushNotificationTypeType,
+        "Title": NotRequired[str],
+        "Body": NotRequired[str],
+        "Type": NotRequired[PushNotificationTypeType],
     },
-    total=False,
 )
 
-_RequiredPushNotificationPreferencesTypeDef = TypedDict(
-    "_RequiredPushNotificationPreferencesTypeDef",
+PushNotificationPreferencesTypeDef = TypedDict(
+    "PushNotificationPreferencesTypeDef",
     {
         "AllowNotifications": AllowNotificationsType,
+        "FilterRule": NotRequired[str],
     },
 )
-_OptionalPushNotificationPreferencesTypeDef = TypedDict(
-    "_OptionalPushNotificationPreferencesTypeDef",
-    {
-        "FilterRule": str,
-    },
-    total=False,
-)
-
-
-class PushNotificationPreferencesTypeDef(
-    _RequiredPushNotificationPreferencesTypeDef, _OptionalPushNotificationPreferencesTypeDef
-):
-    pass
-
 
 PutChannelMembershipPreferencesRequestRequestTypeDef = TypedDict(
     "PutChannelMembershipPreferencesRequestRequestTypeDef",
@@ -1281,8 +1056,8 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredSendChannelMessageRequestRequestTypeDef = TypedDict(
-    "_RequiredSendChannelMessageRequestRequestTypeDef",
+SendChannelMessageRequestRequestTypeDef = TypedDict(
+    "SendChannelMessageRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "Content": str,
@@ -1290,25 +1065,11 @@ _RequiredSendChannelMessageRequestRequestTypeDef = TypedDict(
         "Persistence": ChannelMessagePersistenceTypeType,
         "ClientRequestToken": str,
         "ChimeBearer": str,
+        "Metadata": NotRequired[str],
+        "PushNotification": NotRequired["PushNotificationConfigurationTypeDef"],
+        "MessageAttributes": NotRequired[Mapping[str, "MessageAttributeValueTypeDef"]],
     },
 )
-_OptionalSendChannelMessageRequestRequestTypeDef = TypedDict(
-    "_OptionalSendChannelMessageRequestRequestTypeDef",
-    {
-        "Metadata": str,
-        "PushNotification": "PushNotificationConfigurationTypeDef",
-        "MessageAttributes": Mapping[str, "MessageAttributeValueTypeDef"],
-    },
-    total=False,
-)
-
-
-class SendChannelMessageRequestRequestTypeDef(
-    _RequiredSendChannelMessageRequestRequestTypeDef,
-    _OptionalSendChannelMessageRequestRequestTypeDef,
-):
-    pass
-
 
 SendChannelMessageResponseTypeDef = TypedDict(
     "SendChannelMessageResponseTypeDef",
@@ -1361,30 +1122,16 @@ UpdateChannelFlowResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateChannelMessageRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateChannelMessageRequestRequestTypeDef",
+UpdateChannelMessageRequestRequestTypeDef = TypedDict(
+    "UpdateChannelMessageRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "MessageId": str,
         "ChimeBearer": str,
+        "Content": NotRequired[str],
+        "Metadata": NotRequired[str],
     },
 )
-_OptionalUpdateChannelMessageRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateChannelMessageRequestRequestTypeDef",
-    {
-        "Content": str,
-        "Metadata": str,
-    },
-    total=False,
-)
-
-
-class UpdateChannelMessageRequestRequestTypeDef(
-    _RequiredUpdateChannelMessageRequestRequestTypeDef,
-    _OptionalUpdateChannelMessageRequestRequestTypeDef,
-):
-    pass
-
 
 UpdateChannelMessageResponseTypeDef = TypedDict(
     "UpdateChannelMessageResponseTypeDef",
@@ -1412,29 +1159,16 @@ UpdateChannelReadMarkerResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateChannelRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateChannelRequestRequestTypeDef",
+UpdateChannelRequestRequestTypeDef = TypedDict(
+    "UpdateChannelRequestRequestTypeDef",
     {
         "ChannelArn": str,
         "Name": str,
         "Mode": ChannelModeType,
         "ChimeBearer": str,
+        "Metadata": NotRequired[str],
     },
 )
-_OptionalUpdateChannelRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateChannelRequestRequestTypeDef",
-    {
-        "Metadata": str,
-    },
-    total=False,
-)
-
-
-class UpdateChannelRequestRequestTypeDef(
-    _RequiredUpdateChannelRequestRequestTypeDef, _OptionalUpdateChannelRequestRequestTypeDef
-):
-    pass
-
 
 UpdateChannelResponseTypeDef = TypedDict(
     "UpdateChannelResponseTypeDef",
